/*  BMPx - The Dumb Music Player
 *  Copyright (C) 2005-2007 BMPx development team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id$
 */

#ifndef BMP_SANITY_HPP
#define BMP_SANITY_HPP

#include <glib/gmacros.h>

G_BEGIN_DECLS

gchar *sanity_check_glib ();
gchar *sanity_check_gtk ();
gchar *sanity_check_libs ();

G_END_DECLS

#endif
